package com.fr.plugin.it.handler;

import com.fr.decision.fun.impl.BaseHttpHandler;
import com.fr.json.JSONObject;
import com.fr.plugin.it.api.FlowApi;
import com.fr.plugin.it.utils.ResponseUtils;
import com.fr.plugin.it.utils.Utils;
import com.fr.plugin.transform.FunctionRecorder;
import com.fr.third.springframework.web.bind.annotation.RequestMethod;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

@FunctionRecorder
public class FlowOperate extends BaseHttpHandler {


    public FlowOperate() {
    }

    @Override
    public RequestMethod getMethod() {
        return RequestMethod.GET;
    }

    @Override
    public String getPath() {
        return "/flowOperate";
    }

    @Override
    public boolean isPublic() {
        return true;
    }

    @Override
    public void handle(HttpServletRequest req, HttpServletResponse res) throws Exception {
        String operateName = req.getParameter("operateName");

        if("startWorkflow".equals(operateName)){
            Object[] param = new Object[5];
            String workflowCode = req.getParameter("workflowCode");
            String userCode = req.getParameter("userCode");
            String finishStart = req.getParameter("finishStart");
            String jsonDataItemsStr = req.getParameter("jsonDataItems");
            String subJsonDataItems = req.getParameter("subJsonDataItems");


            param[0] =workflowCode;
            param[1] =userCode;
            param[2] =finishStart;
            param[3] =jsonDataItemsStr;
            param[4] = subJsonDataItems;

            String result = FlowApi.startFlow(param);

            if(Utils.isNullStr(result)){
                ResponseUtils.failedResponse(res,"流程操作失败(500)!");
                return ;
            }

            JSONObject json = new JSONObject(result);
            boolean success = json.getBoolean("Success");
            String msg = json.getString("Message");

            if(success){
                ResponseUtils.successResponse(res,msg);
            }else{
                ResponseUtils.failedResponse(res,msg);
            }

        }
        else if("returnWorkItem".equals(operateName)){
            Object[] param = new Object[4];
            String userCode = req.getParameter("userCode");
            String workItemId = req.getParameter("workItemId");
            String commentText = req.getParameter("commentText");

            param[0] =userCode;
            param[1] =workItemId;
            param[2] =commentText;

            String result = FlowApi.return1(param);
            if(Utils.isNullStr(result)){
                ResponseUtils.failedResponse(res,"流程操作失败(500)!");
                return ;
            }
            ResponseUtils.successResponse(res,result);
        }
        else if("returnWorkflowToStart".equals(operateName)){
            Object[] param = new Object[4];
            String workItemId = req.getParameter("workItemId");
            String commentText = req.getParameter("commentText");

            param[0] =workItemId;
            param[1] =commentText;

            String result = FlowApi.returnToStart(param);
            if(Utils.isNullStr(result)){
                ResponseUtils.failedResponse(res,"流程操作失败(500)!");
                return ;
            }
            ResponseUtils.successResponse(res,result);
        }
        else if("submitWorkItem".equals(operateName)){
            Object[] param = new Object[4];
            String userCode = req.getParameter("userCode");
            String workItemId = req.getParameter("workItemId");
            String commentText = req.getParameter("commentText");
            String approval = req.getParameter("approval");

            param[0] =userCode;
            param[1] =workItemId;
            param[2] =commentText;
            param[3] =approval;

            String result = FlowApi.submit(param);
            if(Utils.isNullStr(result)){
                ResponseUtils.failedResponse(res,"流程操作失败(500)!");
                return ;
            }
            ResponseUtils.successResponse(res,result);
        }
        else if("cancelInstances".equals(operateName)){
            Object[] param = new Object[4];
            String userCode = req.getParameter("userCode");
            String sequenceNos = req.getParameter("instanceId");

            param[0] =userCode;
            param[1] =sequenceNos;

            String result = FlowApi.cancel(param);
            if(Utils.isNullStr(result)){
                ResponseUtils.failedResponse(res,"流程操作失败(500)!");
                return ;
            }
            ResponseUtils.successResponse(res,result);
        }
        else if("cancelInstanceWithRemark".equals(operateName)){
            Object[] param = new Object[3];
            String userCode = req.getParameter("userCode");
            String sequenceNos = req.getParameter("instanceId");
            String remark = req.getParameter("remark");

            param[0] =userCode;
            param[1] =sequenceNos;
            param[2] =remark;

            String result = FlowApi.cancelWithRemark(param);
            if(Utils.isNullStr(result)){
                ResponseUtils.failedResponse(res,"流程操作失败(500)!");
                return ;
            }
            ResponseUtils.successResponse(res,result);
        }
        else if("reStartWorkflow".equals(operateName)){
            Object[] param = new Object[2];
            String userCode = req.getParameter("instanceId");
            String sequenceNos = req.getParameter("activityCode");

            param[0] =userCode;
            param[1] =sequenceNos;

            String result = FlowApi.restart(param);
            if(Utils.isNullStr(result)){
                ResponseUtils.failedResponse(res,"流程操作失败(500)!");
                return ;
            }
            ResponseUtils.successResponse(res,result);
        }
        else if("getPostByUserCode".equals(operateName)){
            Object[] param = new Object[3];
            String codes = req.getParameter("codes");
            String orgUnits = req.getParameter("orgUnits");
            String flag = req.getParameter("flag");

            param[0] =codes;
            param[1] =orgUnits;
            param[2] =flag;

            String result = FlowApi.org(param);
            if(Utils.isNullStr(result)){
                ResponseUtils.failedResponse(res,"流程操作失败(500)!");
                return ;
            }
            ResponseUtils.successResponse(res,result);
        }
    }




}

